@@ -37,7 +37,7 @@ auto_test <- function(code_path, test_path, reporter = "summary") {
   test_dir(test_path)
   
   starts_with <- function(string, prefix) {
-    substr(string, 1, nchar(prefix)) == prefix
+    str_sub(string, 1, str_length(prefix)) == prefix
   }
   
   # Next set up watcher to monitor changes
@@ -49,13 +49,13 @@ auto_test <- function(code_path, test_path, reporter = "summary") {
     
     if (length(code) > 0) {
       # Reload code and rerun all tests
-      cat("Changed code: ", paste(basename(code), collapse = ", "), "\n")
+      cat("Changed code: ", str_c(basename(code), collapse = ", "), "\n")
       cat("Rerunning all tests\n")
       lapply(code, source, chdir = TRUE)
       test_dir(test_path)
     } else if (length(tests) > 0) {
       # If test changes, rerun just that test
-      cat("Rerunning tests: ", paste(basename(tests), collapse = ", "), "\n")      
+      cat("Rerunning tests: ", str_c(basename(tests), collapse = ", "), "\n")      
       with_reporter(reporter$clone(), lapply(tests, source, chdir = TRUE))
     }
     
