@@ -9,9 +9,12 @@ NULL
 
 Reporter$do({
   self$context <- ""
-  self$test <- ""
+  self$test <- NULL
+  self$failed <- FALSE
     
-  self$start_reporter <- function() {}
+  self$start_reporter <- function() {
+    self$failed <- FALSE
+  }
   self$start_context <- function(desc) {
     self$context <- desc
   }
@@ -19,7 +22,9 @@ Reporter$do({
     self$test <- desc
   }
   self$add_result <- function(result) {}
-  self$end_test <- function() {}
+  self$end_test <- function() {
+    self$test <- NULL
+  }
   self$end_context <- function() {}
   self$end_reporter <- function() {}
 })
